import * as prompts from "@clack/prompts";
import { doesRepositoryExist } from "../doesRepositoryExist.js";
import { filterPromptCancel } from "../prompts.js";
import { createRepositoryWithApi } from "./createRepositoryWithApi.js";
async function ensureRepositoryExists(github, options) {
  let { repository } = options;
  let createRepository = options.mode === "create";
  while (github) {
    if (await doesRepositoryExist(github.octokit, options)) {
      return { github, repository };
    }
    const selection = createRepository ? "create" : filterPromptCancel(
      await prompts.select({
        message: `Repository ${options.repository} doesn't seem to exist under ${options.owner}. What would you like to do?`,
        options: [
          { label: "Create a new repository", value: "create" },
          {
            label: "Switch to a different repository name",
            value: "different"
          },
          {
            label: "Keep changes local",
            value: "local"
          },
          { label: "Bail out and maybe try again later", value: "bail" }
        ]
      })
    );
    createRepository = false;
    switch (selection) {
      case void 0:
      case "bail":
        return {};
      case "create":
        await createRepositoryWithApi(github.octokit, {
          owner: options.owner,
          preserveGeneratedFrom: options.preserveGeneratedFrom,
          repository
        });
        return { github, repository };
      case "different":
        const newRepository = filterPromptCancel(
          await prompts.text({
            message: `What would you like to call the repository?`
          })
        );
        if (!newRepository) {
          return {};
        }
        repository = newRepository;
        break;
      case "local":
        github = void 0;
        break;
    }
  }
  return { github, repository };
}
export {
  ensureRepositoryExists
};
//# sourceMappingURL=ensureRepositoryExists.js.map